Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(481)

Unified Diff: tools/image_expectations.h

Issue 1316233002: Style Change: NULL->nullptr (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: 2015-08-27 (Thursday) 10:25:06 EDT Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tools/gpuveto.cpp ('k') | tools/image_expectations.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tools/image_expectations.h
diff --git a/tools/image_expectations.h b/tools/image_expectations.h
index 422c64d4eda78b379c6fa6495fd941fdc084ac2d..a72d7a2c4673433dcb8cb8553ab9161e350761b0 100644
--- a/tools/image_expectations.h
+++ b/tools/image_expectations.h
@@ -171,10 +171,10 @@ namespace sk_tools {
* @param sourceName name of the source file that generated this result
* @param fileName relative path to the image output file on local disk
* @param digest description of the image's contents
* @param tileNumber if not NULL, pointer to tile number
*/
void add(const char *sourceName, const char *fileName, ImageDigest &digest,
- const int *tileNumber=NULL);
+ const int *tileNumber=nullptr);
/**
* Adds a key/value pair to the descriptions dict within the summary of results.
@@ -195,12 +195,12 @@ namespace sk_tools {
* Returns the Expectation for this test.
*
* @param sourceName name of the source file that generated this result
* @param tileNumber if not NULL, pointer to tile number
*
* TODO(stephana): To make this work for GMs, we will need to add parameters for
* config, and maybe renderMode/builder?
*/
- Expectation getExpectation(const char *sourceName, const int *tileNumber=NULL);
+ Expectation getExpectation(const char *sourceName, const int *tileNumber=nullptr);
/**
* Writes the summary (as constructed so far) to a file.
« no previous file with comments | « tools/gpuveto.cpp ('k') | tools/image_expectations.cpp » ('j') | no next file with comments »
@@ -171,10 +171,10 @@ namespace sk_tools {
* @param fileName relative path to the image output file on local disk
* @param digest description of the image's contents
- * @param tileNumber if not NULL, pointer to tile number
+ * @param tileNumber if not nullptr, pointer to tile number
*/
void add(const char *sourceName, const char *fileName, ImageDigest &digest,
@@ -195,12 +195,12 @@ namespace sk_tools {
*
* @param sourceName name of the source file that generated this result
- * @param tileNumber if not NULL, pointer to tile number
+ * @param tileNumber if not nullptr, pointer to tile number
*
* TODO(stephana): To make this work for GMs, we will need to add parameters for

Powered by Google App Engine
This is Rietveld 408576698